@@ -50,7 +50,6 @@ ggtsbreaks <- function(x) {
 }
 
 
-
 #' ggplot (Partial) Autocorrelation and Cross-Correlation Function Estimation
 #' and Plotting
 #'
@@ -114,7 +113,7 @@ autoplot.acf <- function(object, ci=0.95, ...) {
     data <- as.data.frame.table(acf)[-1]
     data$lag <- as.numeric(lag)
 
-    if (object$type == "correlation") {
+    if (object$type == "correlation" & is.null(object$ccf)) {
       data <- data[data$lag != 0, ]
     }
 
@@ -191,14 +190,10 @@ autoplot.acf <- function(object, ci=0.95, ...) {
 ggAcf <- function(x, lag.max = NULL,
                   type = c("correlation", "covariance", "partial"),
                   plot = TRUE, na.action = na.contiguous, demean=TRUE, ...) {
-  cl <- match.call()
-  if (plot) {
-    cl$plot <- FALSE
-  }
-  cl[[1]] <- quote(Acf)
-  object <- eval.parent(cl)
+  object <- Acf(x, lag.max = lag.max, type = type, na.action = na.action, demean = demean, plot = FALSE)
   object$tsp <- tsp(x)
   object$periods <- attributes(x)$msts
+  object$series <- deparse(substitute(x))
   if (plot) {
     return(autoplot(object, ...))
   }
@@ -212,6 +207,8 @@ ggAcf <- function(x, lag.max = NULL,
 ggPacf <- function(x, lag.max = NULL,
                    plot = TRUE, na.action = na.contiguous, demean=TRUE, ...) {
   object <- Acf(x, lag.max = lag.max, type = "partial", na.action = na.action, demean = demean, plot = FALSE)
+  object$tsp <- tsp(x)
+  object$periods <- attributes(x)$msts
   object$series <- deparse(substitute(x))
   if (plot) {
     return(autoplot(object, ...))
@@ -224,12 +221,7 @@ ggPacf <- function(x, lag.max = NULL,
 #' @export
 ggCcf <- function(x, y, lag.max=NULL, type=c("correlation", "covariance"),
                   plot=TRUE, na.action=na.contiguous, ...) {
-  cl <- match.call()
-  if (plot) {
-    cl$plot <- FALSE
-  }
-  cl[[1]] <- quote(Ccf)
-  object <- eval.parent(cl)
+  object <- Ccf(x, y, lag.max = lag.max, type = type, na.action = na.action, plot = FALSE)
   object$snames <- paste(deparse(substitute(x)), "&", deparse(substitute(y)))
   object$ccf <- TRUE
   if (plot) {
@@ -738,7 +730,6 @@ Interval shading is now done automatically based on the level and `fcol`.",
       #   # Negative group is a work around for missing z-index
       # }
 
-
       # # Forecasted points
       # p <- p + ggplot2::geom_line(ggplot2::aes_(x = ~datetime, y = ~ypred), data = predicted, color = fcol, size = flwd)
     }
@@ -946,7 +937,6 @@ ggtsdisplay <- function(x, plot.type=c("partial", "histogram", "scatter", "spect
 }
 
 
-
 #' Time series lag ggplots
 #'
 #' Plots a lag plot using ggplot.
@@ -1170,7 +1160,6 @@ gglagchull <- function(x,
 }
 
 
-
 #' Create a seasonal subseries ggplot
 #'
 #' Plots a subseries plot using ggplot. Each season is plotted as a separate
@@ -1248,7 +1237,14 @@ ggsubseriesplot <- function(x, labels = NULL, times = time(x), phase = cycle(x),
 
     # Create x-axis labels
     xfreq <- frequency(x)
-    if (xfreq == 4) {
+    if (!is.null(labels)) {
+      if (xfreq != length(labels)) {
+        stop("The number of labels supplied is not the same as the number of seasons.")
+      } else {
+        xbreaks <- labels
+      }
+    }
+    else if (xfreq == 4) {
       xbreaks <- c("Q1", "Q2", "Q3", "Q4")
       xlab <- "Quarter"
     }
@@ -1568,7 +1564,6 @@ autoplot.StructTS <- function(object, labels = NULL, range.bars = TRUE, ...) {
 }
 
 
-
 #' Plot time series decomposition components using ggplot
 #'
 #' Produces a ggplot object of seasonally decomposed time series for objects of
@@ -1781,7 +1776,6 @@ autolayer.mforecast <- function(object, series = NULL, PI = TRUE, ...) {
 }
 
 
-
 #' Automatically create a ggplot for time series objects
 #'
 #' \code{autoplot} takes an object of type \code{ts} or \code{mts} and creates
@@ -2125,7 +2119,6 @@ GeomForecastPoint <- ggplot2::ggproto(
   }
 )
 
-
 blendHex <- function(mixcol, seqcol, alpha=1) {
   requireNamespace("methods")
   if (is.na(seqcol)) {
@@ -2198,7 +2191,6 @@ GeomForecastInterval <- ggplot2::ggproto(
 
 
 
-
 #' Forecast plot
 #'
 #' Generates forecasts from \code{forecast.ts} and adds them to the plot.
@@ -2326,7 +2318,6 @@ geom_forecast <- function(mapping = NULL, data = NULL, stat = "forecast",
 # Designed to work with time series data without issuing warnings.
 
 
-
 #' Histogram with optional normal and kernel density functions
 #'
 #' Plots a histogram and density estimates using ggplot.
